@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/util.c
  *
- * Copyright (C) 2005-2009  NTT DATA CORPORATION
+ * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.7.1+   2009/12/20
+ * Version: 1.7.3+   2012/05/05
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -211,7 +211,7 @@ bool ccs_parse_name_union(const char *filename, struct ccs_name_union *ptr)
  * ccs_parse_number_union - Parse a ccs_number_union.
  *
  * @data: Number or number range or number group.
- * @ptr:  Pointer to "struct ccs_number_union".
+ * @num:  Pointer to "struct ccs_number_union".
  *
  * Returns true on success, false otherwise.
  */
@@ -248,7 +248,7 @@ bool ccs_parse_number_union(char *data, struct ccs_number_union *num)
 }
 
 /**
- * ccs_is_byte_range - Check whether the string isa \ooo style octal value.
+ * ccs_is_byte_range - Check whether the string is a \ooo style octal value.
  *
  * @str: Pointer to the string.
  *
@@ -780,7 +780,7 @@ static bool ccs_file_matches_pattern2(const char *filename,
 }
 
 /**
- * ccs_file_matches_pattern - Pattern matching without without '/' character.
+ * ccs_file_matches_pattern - Pattern matching without '/' character.
  *
  * @filename:     The start of string to check.
  * @filename_end: The end of string to check.
@@ -1009,20 +1009,14 @@ int ccs_get_mode(const u8 profile, const u8 index)
  * ccs_init_request_info - Initialize "struct ccs_request_info" members.
  *
  * @r:      Pointer to "struct ccs_request_info" to initialize.
- * @domain: Pointer to "struct ccs_domain_info". NULL for ccs_current_domain().
  * @index:  Index number of functionality.
  *
  * Returns mode.
  */
-int ccs_init_request_info(struct ccs_request_info *r,
-			  struct ccs_domain_info *domain, const u8 index)
+int ccs_init_request_info(struct ccs_request_info *r, const u8 index)
 {
-	u8 profile;
+	const u8 profile = ccs_current_domain()->profile;
 	memset(r, 0, sizeof(*r));
-	if (!domain)
-		domain = ccs_current_domain();
-	r->domain = domain;
-	profile = domain->profile;
 	r->profile = profile;
 	r->type = index;
 	r->mode = ccs_get_mode(profile, index);
@@ -1032,7 +1026,7 @@ int ccs_init_request_info(struct ccs_request_info *r,
 /**
  * ccs_last_word - Get last component of a line.
  *
- * @line: A line.
+ * @name: A line.
  *
  * Returns the last word of a line.
  */
@@ -1055,8 +1049,8 @@ void ccs_warn_log(struct ccs_request_info *r, const char *fmt, ...)
 	int len = PAGE_SIZE;
 	va_list args;
 	char *buffer;
-	const struct ccs_profile *profile =
-		ccs_profile(r->domain->profile);
+	const struct ccs_domain_info * const domain = ccs_current_domain();
+	const struct ccs_profile *profile = ccs_profile(domain->profile);
 	switch (r->mode) {
 	case CCS_CONFIG_ENFORCING:
 		if (!profile->enforcing->enforcing_verbose)
@@ -1073,7 +1067,7 @@ void ccs_warn_log(struct ccs_request_info *r, const char *fmt, ...)
 	}
 	while (1) {
 		int len2;
-		buffer = kmalloc(len, GFP_KERNEL);
+		buffer = kmalloc(len, CCS_GFP_FLAGS);
 		if (!buffer)
 			return;
 		va_start(args, fmt);
@@ -1088,7 +1082,7 @@ void ccs_warn_log(struct ccs_request_info *r, const char *fmt, ...)
 	}
 	printk(KERN_WARNING "%s: Access %s denied for %s\n",
 	       r->mode == CCS_CONFIG_ENFORCING ? "ERROR" : "WARNING", buffer,
-	       ccs_last_word(r->domain->domainname->name));
+	       ccs_last_word(domain->domainname->name));
 	kfree(buffer);
 }
 
@@ -1104,9 +1098,9 @@ void ccs_warn_log(struct ccs_request_info *r, const char *fmt, ...)
 bool ccs_domain_quota_ok(struct ccs_request_info *r)
 {
 	unsigned int count = 0;
-	struct ccs_domain_info *domain = r->domain;
+	struct ccs_domain_info * const domain = ccs_current_domain();
 	struct ccs_acl_info *ptr;
-	if (r->mode != 1)
+	if (r->mode != CCS_CONFIG_LEARNING)
 		return false;
 	if (!domain)
 		return true;
